@@ -9,6 +9,7 @@ import pandas as pd
 import requests
 from lxml import etree
 
+import pyield.date_converter as dc
 from pyield import bday
 from pyield.b3.futures import common
 from pyield.fwd import forwards
@@ -306,6 +307,7 @@ def fetch_xml_data(
             available for the given date.
     """
     try:
+        date = dc.convert_input_dates(date)
         zip_file = _get_file_from_url(date, source_type)
         df = process_zip_file(zip_file, contract_code)
     except ValueError as e:
